@@ -249,7 +249,7 @@ void DateFormatRoundTripTest::test(const Locale& loc)
     
     for(style = DateFormat::FULL; style <= DateFormat::SHORT; ++style) {
         if (TEST_TABLE[itable++]) {
-          logln("Testing style " + UnicodeString(styleName((DateFormat::EStyle)style)));
+            logln("Testing style " + UnicodeString(styleName((DateFormat::EStyle)style)));
             DateFormat *df = DateFormat::createTimeInstance((DateFormat::EStyle)style, loc);
             if(df == NULL) {
               errln(UnicodeString("Could not DF::createTimeInstance ") + UnicodeString(styleName((DateFormat::EStyle)style)) + " Locale: " + loc.getDisplayName(temp));
@@ -340,8 +340,13 @@ void DateFormatRoundTripTest::test(DateFormat *fmt, const Locale &origLocale, UB
             for(loop = 0; loop < DEPTH; ++loop) {
                 if (loop > 0)  {
                     d[loop] = fmt->parse(s[loop-1], status);
-                    failure(status, "fmt->parse", s[loop-1]+" in locale: " + origLocale.getName() + " with pattern: " + pat);
-                    status = U_ZERO_ERROR; /* any error would have been reported */
+                    if(U_FAILURE(status)) {
+                        ParsePosition ppos;
+                        (void)fmt->parse(s[loop-1], ppos);
+                        failure(status, "fmt->parse", s[loop-1]+" in locale: " + origLocale.getName() +
+                                " with pattern: " + pat + " has errIndex: " + ppos.getErrorIndex());
+                        status = U_ZERO_ERROR; /* any error would have been reported */
+                    }
                 }
 
                 s[loop] = fmt->format(d[loop], s[loop]);
@@ -534,13 +539,16 @@ UnicodeString& DateFormatRoundTripTest::escape(const UnicodeString& src, Unicode
 {
     dst.remove();
     for (int32_t i = 0; i < src.length(); ++i) {
-        UChar c = src[i];
-        if(c < 0x0080) 
+        UChar32 c = src.char32At(i);
+        if (c >= 0x10000) {
+            ++i;
+        }
+        if (c < 0x0080) {
             dst += c;
-        else {
+        } else {
             dst += UnicodeString("[");
-            char buf [8];
-            sprintf(buf, "%#x", c);
+            char buf [12];
+            sprintf(buf, "%#04x", c);
             dst += UnicodeString(buf);
             dst += UnicodeString("]");
         }
