@@ -1,4 +1,4 @@
-// Copyright (C) 2016 and later: Unicode, Inc. and others.
+// © 2016 and later: Unicode, Inc. and others.
 // License & terms of use: http://www.unicode.org/copyright.html
 /********************************************************************
  * COPYRIGHT: 
@@ -34,8 +34,8 @@ public:
     void TestJapanese(void);
     void TestJapaneseFormat(void);
     void TestJapanese3860(void);
-    void TestJapaneseHeiseiToReiwa(void);
-
+    void TestForceGannenNumbering(void);
+    
     void TestPersian(void);
     void TestPersianFormat(void);
 
